@@ -5,7 +5,7 @@ use warnings;
 package Z;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.004';
+our $VERSION   = '0.005';
 
 use Import::Into ();
 use Module::Runtime qw( use_module );
@@ -19,7 +19,7 @@ sub import {
 	my ($target, $class ) = ( scalar caller, shift );
 	
 	my $mode = '-modern';
-	$mode = shift if $_[0] =~ /^-/;
+	( $_[0] || '' ) =~ /^-/ and $mode = shift;
 	
 	my $collection = 'modules';
 	
